You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@nuttx.apache.org by xi...@apache.org on 2020/06/05 04:21:58 UTC

[incubator-nuttx] 04/05: arch/arm/src/stm32/stm32_i2s: Change the initialize function from stm32_i2sdev_initialize to stm32_i2sbus_initiliaze, to be consistent with the way other buses are initialized. The stm32_i2sdev_initiliaze (similar to stm32_spidev_initialize for example) is a board specific function that does any necessary initialization that's board depedent.

This is an automated email from the ASF dual-hosted git repository.

xiaoxiang pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/incubator-nuttx.git

commit 1ca552716c4a66d010db266910e496c9ab38d06a
Author: Ouss4 <ab...@gmail.com>
AuthorDate: Wed Jun 3 20:43:57 2020 +0100

    arch/arm/src/stm32/stm32_i2s: Change the initialize function from
    stm32_i2sdev_initialize to stm32_i2sbus_initiliaze, to be consistent
    with the way other buses are initialized.
    The stm32_i2sdev_initiliaze (similar to stm32_spidev_initialize for
    example) is a board specific function that does any necessary
    initialization that's board depedent.
---
 arch/arm/src/stm32/stm32_i2s.c                           | 6 +++---
 arch/arm/src/stm32/stm32_i2s.h                           | 4 ++--
 boards/arm/stm32/stm32f4discovery/src/stm32_cs43l22.c    | 2 +-
 boards/arm/stm32/stm32f4discovery/src/stm32f4discovery.h | 2 +-
 4 files changed, 7 insertions(+), 7 deletions(-)

diff --git a/arch/arm/src/stm32/stm32_i2s.h b/arch/arm/src/stm32/stm32_i2s.h
index 29e1cce..b14a18d 100644
--- a/arch/arm/src/stm32/stm32_i2s.h
+++ b/arch/arm/src/stm32/stm32_i2s.h
@@ -65,7 +65,7 @@ extern "C"
  ************************************************************************************/
 
 /************************************************************************************
- * Name: stm32_i2sdev_initialize
+ * Name: stm32_i2sbus_initialize
  *
  * Description:
  *   Initialize the selected I2S port
@@ -78,7 +78,7 @@ extern "C"
  *
  ************************************************************************************/
 
-FAR struct i2s_dev_s *stm32_i2sdev_initialize(int port);
+FAR struct i2s_dev_s *stm32_i2sbus_initialize(int port);
 
 #undef EXTERN
 #if defined(__cplusplus)
diff --git a/boards/arm/stm32/stm32f4discovery/src/stm32_cs43l22.c b/boards/arm/stm32/stm32f4discovery/src/stm32_cs43l22.c
index d66eabe..40e9c44 100644
--- a/boards/arm/stm32/stm32f4discovery/src/stm32_cs43l22.c
+++ b/boards/arm/stm32/stm32f4discovery/src/stm32_cs43l22.c
@@ -297,7 +297,7 @@ int stm32_cs43l22_initialize(int minor)
         }
       /* Get an instance of the I2S interface for the CS43L22 data channel */
 
-      i2s = stm32_i2sdev_initialize(CS43L22_I2S_BUS);
+      i2s = stm32_i2sbus_initialize(CS43L22_I2S_BUS);
       if (!i2s)
         {
           auderr("ERROR: Failed to initialize I2S%d\n", CS43L22_I2S_BUS);
diff --git a/boards/arm/stm32/stm32f4discovery/src/stm32f4discovery.h b/boards/arm/stm32/stm32f4discovery/src/stm32f4discovery.h
index 7b04f90..beed99d 100644
--- a/boards/arm/stm32/stm32f4discovery/src/stm32f4discovery.h
+++ b/boards/arm/stm32/stm32f4discovery/src/stm32f4discovery.h
@@ -438,7 +438,7 @@ void weak_function stm32_spidev_initialize(void);
  *
  ****************************************************************************/
 
-FAR struct i2s_dev_s *stm32_i2sdev_initialize(int port);
+void weak_function stm32_i2sdev_initialize(void);
 
 /****************************************************************************
  * Name: stm32_bh1750initialize
diff --git a/arch/arm/src/stm32/stm32_i2s.c b/arch/arm/src/stm32/stm32_i2s.c
index 3de5619..4762abd 100644
--- a/arch/arm/src/stm32/stm32_i2s.c
+++ b/arch/arm/src/stm32/stm32_i2s.c
@@ -49,7 +49,7 @@
  *      is configured.
  *   3. Add a calls to up_spiinitialize() in your low level application
  *      initialization logic
  *   4. The handle returned by stm32_i2sdev_initialize() may then be used to
  *     bind the I2S driver to higher level logic
  *
  ****************************************************************************/
@@ -2604,7 +2604,7 @@ static void i2s3_configure(struct stm32_i2s_s *priv)
  ****************************************************************************/
 
 /****************************************************************************
- * Name: stm32_i2sdev_initialize
+ * Name: stm32_i2sbus_initialize
  *
  * Description:
  *   Initialize the selected i2S port
@@ -2617,7 +2617,7 @@ static void i2s3_configure(struct stm32_i2s_s *priv)
  *
  ****************************************************************************/
 
-FAR struct i2s_dev_s *stm32_i2sdev_initialize(int port)
+FAR struct i2s_dev_s *stm32_i2sbus_initialize(int port)
 {
   FAR struct stm32_i2s_s *priv = NULL;
   irqstate_t flags;
@@ -49,7 +49,7 @@
  *   3. Add a calls to up_spiinitialize() in your low level application
  *      initialization logic
- *   4. The handle returned by stm32_i2sdev_initialize() may then be used to
+ *   4. The handle returned by stm32_i2sbus_initialize() may then be used to
  *     bind the I2S driver to higher level logic
  *